//    Black Penguin - Game for Linux
//    Copyright (C) 1999 Holger Priebs, pengu@priebs.de
//
//    Holger Priebs
//    Hasselkamp 39
//    D - 24119 Kronshagen / Germany
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef BlackPenguinData_included
#define BlackPenguinData_included

#include <qframe.h>
#include <qlabel.h>
#include <qpushbt.h>
#include <qlcdnum.h>
#include <qevent.h>

#define maxbackgrounds 4
#define maxlevels 16
#define maxgoodies 10

class BP
{

public:
	BP();
	~BP();
	void  show(QPaintDevice* qpd);
	void  down();
	void    up();
	void right();
	void  left();
	int m_position;
	
protected: 
	QPixmap* m_penguBP;
	QPixmap* m_pengumaskBP;
	QBitmap* m_bm_pengumaskBP;
	
};


class Goodies
{

public:
	Goodies();
	~Goodies();
	void  show(QPaintDevice* qpd);
	
protected: 
	QPixmap* m_goodiesBP[maxgoodies];
	QPixmap* m_goodiesmaskBP[maxgoodies];
	QBitmap* m_bm_goodiesmaskBP[maxgoodies];
	
};

class Foe
{

public:
	Foe();
	~Foe();
	void  show(QPaintDevice* qpd);
	void  update(int penguposition);
	void  reset();
	int current_pos();
	int cancapture(int fposition, int penguposition);
	int iscaptured(int fposition, int penguposition);
	void setposition(int there);
	int legal_move(int position); // determine whether move is legal
	
protected: 
	QPixmap* m_foeBP;
	QPixmap* m_foemaskBP;
	QBitmap* m_bm_foemaskBP;
	int m_position;
	int counter;
};

class BlackPenguinData : public QWidget
{
    Q_OBJECT

public:

	BlackPenguinData
	(
		QWidget* parent = NULL,
		const char* name = NULL
	);


	virtual ~BlackPenguinData();

	void increaselevel();
	int savegame();
	int loadgame();
	int savekeys();
	int loadkeys();

// --------
// added by Olaf Hartig 11 Nov 1999

	int getKeyNW() const { return m_nKeyNW; }
	int getKeyNE() const { return m_nKeyNE; }
	int getKeySW() const { return m_nKeySW; }
	int getKeySE() const { return m_nKeySE; }
// --------

// dummy key event

	// we need this because updating screen is handled in conjunction with kbd events
	QKeyEvent* m_keydummy;

public slots:

	void timerevent();
	void reset(); // reset anything for a new game
	void resetround(); // pengu jumped off and gets a new chance
// -------- 
// added by Olaf Hartig 11 Nov 1999
	void newKeys(int nKeyNW, int nKeyNE, int nKeySW, int nKeySE);
// --------

protected slots:


protected:

	QPushButton* B1;
	QLCDNumber* LCDcounter;
	QLCDNumber* LCDcounter2;
	QLCDNumber* LCDcounter3;

// -------- 
// added by Olaf Hartig 11 Nov 1999
	int m_nKeyNW;
	int m_nKeyNE;	
	int m_nKeySW;
	int m_nKeySE;
// --------
	
// handle paint events

	void paintEvent( QPaintEvent* );
	void keyPressEvent( QKeyEvent* e );

// calculate the amount of credits we can get in the current level

	void calculate_credits();

// Pixmap for the background and a second one for double buffering

	QPixmap* m_invisible_bg[maxbackgrounds]; // from here we get a blank background
	QPixmap* m_visible_bg; // this Pixmap is blitted to the screen

// 'got you' pixmap

	QPixmap* m_gotcha;
	QPixmap* m_gotchamask;
	QBitmap* m_gotchamaskBM;

// pixmap you lose one life

	QPixmap* m_minusone;

// pixmap 'prepare for next level

	QPixmap* m_nextlevel;

// 'game over' pixmap

	QPixmap* m_gameover;

// 'you win' pixmap

	QPixmap* m_youwin;

// pointer variable to the penguin's class

	BP* pbp;
	Goodies* pg;
	Foe* pfoe;

// for triggering the foe

	QTimer* ptimer;

};



#endif // BlackPenguinData_included
